@@ -20,6 +20,7 @@ sub load_registry {
 
 sub process {
     $self->load_registry;
+    $self->preload;
     my $action = $self->action;
     die "No plugin for action '$action'"
       unless defined $self->registry->lookup->action->{$action};
@@ -31,6 +32,19 @@ sub process {
     return $self->$class_id->$method;
 }
 
+sub preload {
+    my $preload = $self->registry->lookup->preload;
+    map {
+        $self->load_class($_->[0])
+    } sort {
+        $b->[1] <=> $a->[1]
+    } map {
+        my %hash = @{$preload->{$_}}[1..$#{$preload->{$_}}];
+        [$_, $hash{priority} || 0];
+    } keys %$preload;
+    
+}
+
 sub add_post_process {
     push @{$self->post_process_actions}, [@_];
 }
@@ -71,18 +85,21 @@ sub load_class {
     my $class_name = $self->config->can($class_class)
         ? $self->config->$class_class
         : defined $self->registry
-          ? defined $self->registry->lookup
+          ? (defined $self->registry->lookup and
+             UNIVERSAL::isa($self->registry->lookup, 'Spoon::Lookup')
+            )
             ? $self->registry->lookup->classes->{$class_id}
-            : die "Can't find a class for class_id '$class_id'"
-          : die "Can't find a class for class_id '$class_id'";
+            : Carp::confess "Can't find a class for class_id '$class_id'"
+          : Carp::confess "Can't find a class for class_id '$class_id'";
     $self->create_class_object($class_name, $class_id);
 }
 
 sub create_class_object {
     my ($class_name, $class_id) = @_;
-    die "No class defined for class_id '$class_id'"
+    Carp::confess "No class defined for class_id '$class_id'"
       unless $class_name;
-    eval qq{ require $class_name };
+    eval "require $class_name";
+    die $@ if $@;
     my $object = $class_name->new($self);
     push @{$self->loaded_objects}, $object;
     $class_id ||= $object->class_id;
